|
From: <sv...@va...> - 2009-05-04 06:44:58
|
Author: njn
Date: 2009-05-04 07:44:55 +0100 (Mon, 04 May 2009)
New Revision: 9762
Log:
Sync branch with the trunk.
Modified:
branches/DARWIN/coregrind/m_translate.c
branches/DARWIN/coregrind/m_transtab.c
Modified: branches/DARWIN/coregrind/m_translate.c
===================================================================
--- branches/DARWIN/coregrind/m_translate.c 2009-05-04 06:44:34 UTC (rev 9761)
+++ branches/DARWIN/coregrind/m_translate.c 2009-05-04 06:44:55 UTC (rev 9762)
@@ -661,8 +661,9 @@
/* Vex dumps the final code in here. Then we can copy it off
wherever we like. */
-// GrP fixme 20000 is too small for vecCGSScanConvolveAndIntegrate+268
-#define N_TMPBUF 128000
+/* 60000: should agree with assertion in VG_(add_to_transtab) in
+ m_transtab.c. */
+#define N_TMPBUF 60000
static UChar tmpbuf[N_TMPBUF];
Modified: branches/DARWIN/coregrind/m_transtab.c
===================================================================
--- branches/DARWIN/coregrind/m_transtab.c 2009-05-04 06:44:34 UTC (rev 9761)
+++ branches/DARWIN/coregrind/m_transtab.c 2009-05-04 06:44:55 UTC (rev 9762)
@@ -847,8 +847,10 @@
vg_assert(init_done);
vg_assert(vge->n_used >= 1 && vge->n_used <= 3);
- vg_assert(code_len > 0 && code_len < 128000); // GrP fixme N_TMPBUF from m_translate.c?
+ /* 60000: should agree with N_TMPBUF in m_translate.c. */
+ vg_assert(code_len > 0 && code_len < 60000);
+
if (0)
VG_(printf)("add_to_transtab(entry = 0x%llx, len = %d)\n",
entry, code_len);
|